@@ -42,13 +42,21 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #include "ui/diagnostics.h"
 #include "ui/helpbox.h"
 
+#include <QMovie>
+#include <QClipboard>
+#include <QDebug>
+#include <QSignalMapper>
+#include <QSettings>
+#include <QAction>
+#include <QApplication>
+
 #include "common.h"
 #include "version.h"
 
-#define TICKMAP         QPixmap(tr(":/res/images/tick.png"))
-#define CROSSMAP        QPixmap(tr(":/res/images/cross.png"))
-#define BLANKMAP        QPixmap(tr(":/res/images/blank.png"))
-#define COPYMAP         QPixmap(tr(":/res/images/clipboard.png"))
+#define TICKMAP         QPixmap(":/res/images/tick.png")
+#define CROSSMAP        QPixmap(":/res/images/cross.png")
+#define BLANKMAP        QPixmap(":/res/images/blank.png")
+#define COPYMAP         QPixmap(":/res/images/clipboard.png")
 
 MainWindow::MainWindow(QWidget *parent) :
         QMainWindow(parent),
@@ -311,32 +319,34 @@ void MainWindow::setCurrentPage(int pageIndex, int tab, int slot) {
 
 void MainWindow::resetDeviceInfo() {
     ui->statusLbl->clear();
-    ui->versionLbl->setText(NA);
+    ui->versionLbl->setText(tr(NA));
 
     QString blankBtnSS = QString::fromUtf8(SS_BLANK_BTN);
-    ui->serialNoDecLbl->setText(NA);
-    ui->serialNoHexLbl->setText(NA);
-    ui->serialNoModhexLbl->setText(NA);
+    ui->serialNoDecLbl->setText(tr(NA));
+    ui->serialNoHexLbl->setText(tr(NA));
+    ui->serialNoModhexLbl->setText(tr(NA));
     ui->serialNoDecCopyBtn->setStyleSheet(blankBtnSS);
     ui->serialNoHexCopyBtn->setStyleSheet(blankBtnSS);
     ui->serialNoModhexCopyBtn->setStyleSheet(blankBtnSS);
 
     ui->otpSupportLbl->setPixmap(QPixmap());
-    ui->otpSupportLbl->setText(NA);
+    ui->otpSupportLbl->setText(tr(NA));
     ui->multiConfigSupportLbl->setPixmap(QPixmap());
-    ui->multiConfigSupportLbl->setText(NA);
+    ui->multiConfigSupportLbl->setText(tr(NA));
     ui->oathHotpSupportLbl->setPixmap(QPixmap());
-    ui->oathHotpSupportLbl->setText(NA);
+    ui->oathHotpSupportLbl->setText(tr(NA));
     ui->staticPwdSupportLbl->setPixmap(QPixmap());
-    ui->staticPwdSupportLbl->setText(NA);
+    ui->staticPwdSupportLbl->setText(tr(NA));
     ui->scanCodeSupportLbl->setPixmap(QPixmap());
-    ui->scanCodeSupportLbl->setText(NA);
+    ui->scanCodeSupportLbl->setText(tr(NA));
     ui->chalRespSupportLbl->setPixmap(QPixmap());
-    ui->chalRespSupportLbl->setText(NA);
+    ui->chalRespSupportLbl->setText(tr(NA));
     ui->updatableSupportLbl->setPixmap(QPixmap());
-    ui->updatableSupportLbl->setText(NA);
+    ui->updatableSupportLbl->setText(tr(NA));
     ui->ndefSupportLbl->setPixmap(QPixmap());
-    ui->ndefSupportLbl->setText(NA);
+    ui->ndefSupportLbl->setText(tr(NA));
+    ui->u2fSupportLbl->setPixmap(QPixmap());
+    ui->u2fSupportLbl->setText(tr(NA));
 }
 
 void MainWindow::keyFound(bool found, bool* featuresMatrix, int error) {
@@ -370,10 +380,10 @@ void MainWindow::keyFound(bool found, bool* featuresMatrix, int error) {
         unsigned int version = finder->version();
         if(error == ERR_UNKNOWN_FIRMWARE) {
             ui->statusLbl->setStyleSheet(QString::fromUtf8(SS_YKSTATUS_ERROR));
-            ui->statusLbl->setText(UNKNOWN_FIRMWARE);
+            ui->statusLbl->setText(tr(UNKNOWN_FIRMWARE));
         } else {
             ui->statusLbl->setStyleSheet(QString::fromUtf8(SS_YKSTATUS_SUCCESS));
-            ui->statusLbl->setText(KEY_FOUND);
+            ui->statusLbl->setText(tr(KEY_FOUND));
         }
 
         ui->versionLbl->setText(finder->versionStr());
@@ -385,8 +395,7 @@ void MainWindow::keyFound(bool found, bool* featuresMatrix, int error) {
             pixmap.load(":/res/images/v1-3-not-animated.png");
         } else if(version < YK_VERSION(2,1,4)) {
             movie->setFileName(":/res/images/V2-0-2-1-animated.mng");
-        } else if(version < YK_VERSION(2,2,0)) {
-            // YubiKey NEO
+        } else if(version < YK_VERSION(2,2,0)) { // NEO Beta
             pixmap.load(":/res/images/neo_transparent.png");
         } else if(version % 10 == 9){
             pixmap.load(":/res/images/yubikey_devel.png");
@@ -396,8 +405,14 @@ void MainWindow::keyFound(bool found, bool* featuresMatrix, int error) {
             movie->setFileName(":/res/images/v2-3-animated.mng");
         } else if(version < YK_VERSION(3,3,0)){
             pixmap.load(":/res/images/neo_production.png");
-        } else { // only case left should be version over 3.3, that is neo + u2f
-            pixmap.load(":/res/images/neo_production_33.png");
+        } else if(version < YK_VERSION(4,0,0)) {
+            movie->setFileName(":/res/images/neo_production_33.mng");
+        } else if(version < YK_VERSION(4,1,0)) {
+            movie->setFileName(":/res/images/plus.mng");
+        } else if(version < YK_VERSION(4,2,0)) {
+            movie->setFileName(":/res/images/edge.mng");
+        } else {
+            pixmap.load(":/res/images/blank.png");
         }
         if(pixmap.isNull()) {
             ui->deviceImage->setMovie(movie);
@@ -440,9 +455,9 @@ void MainWindow::keyFound(bool found, bool* featuresMatrix, int error) {
             ui->serialNoHexCopyBtn->setStyleSheet(copyBtnSS);
             ui->serialNoModhexCopyBtn->setStyleSheet(copyBtnSS);
         } else {
-            ui->serialNoDecLbl->setText(NA);
-            ui->serialNoHexLbl->setText(NA);
-            ui->serialNoModhexLbl->setText(NA);
+            ui->serialNoDecLbl->setText(tr(NA));
+            ui->serialNoHexLbl->setText(tr(NA));
+            ui->serialNoModhexLbl->setText(tr(NA));
             ui->serialNoDecCopyBtn->setStyleSheet(blankBtnSS);
             ui->serialNoHexCopyBtn->setStyleSheet(blankBtnSS);
             ui->serialNoModhexCopyBtn->setStyleSheet(blankBtnSS);
@@ -515,6 +530,11 @@ void MainWindow::keyFound(bool found, bool* featuresMatrix, int error) {
         } else {
             ui->ndefSupportLbl->setPixmap(CROSSMAP);
         }
+        if(featuresMatrix[YubiKeyFinder::Feature_U2F]) {
+            ui->u2fSupportLbl->setPixmap(TICKMAP);
+        } else {
+            ui->u2fSupportLbl->setPixmap(CROSSMAP);
+        }
     } else {
         ui->programLbl->clear();
         if(ui->deviceImage->pixmap()) {
@@ -522,11 +542,11 @@ void MainWindow::keyFound(bool found, bool* featuresMatrix, int error) {
         }
         ui->deviceImage->clear();
         if(error == ERR_NOKEY) {
-            ui->statusLbl->setText(NO_KEY_FOUND);
+            ui->statusLbl->setText(tr(NO_KEY_FOUND));
         } else if(error == ERR_MORETHANONE) {
-            ui->statusLbl->setText(MORE_THAN_ONE);
+            ui->statusLbl->setText(tr(MORE_THAN_ONE));
         } else {
-            ui->statusLbl->setText(OTHER_ERROR);
+            ui->statusLbl->setText(tr(OTHER_ERROR));
         }
         ui->statusLbl->setStyleSheet(QString::fromUtf8(SS_YKSTATUS_ERROR));
 
@@ -604,7 +624,7 @@ void MainWindow::copyToClipboard(const QString &str) {
     QClipboard *clipboard = QApplication::clipboard();
     clipboard->setText(str);
 
-    showStatusMessage(VALUE_COPIED, 0);
+    showStatusMessage(tr(VALUE_COPIED), 0);
 }
 
 void MainWindow::on_serialNoDecCopyBtn_clicked() {
