@@ -30,6 +30,7 @@ OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 #define YUBIKEYFINDER_H
 
 #include <QObject>
+#include <QTimer>
 
 extern "C" {
 #include <ykpers.h>
@@ -68,6 +69,7 @@ public:
         Feature_Updatable,
         Feature_Ndef,
         Feature_LedInvert,
+        Feature_U2F,
     };
 
     State state() const
@@ -98,7 +100,7 @@ private:
 
     static YubiKeyFinder* _instance;
     static const unsigned int FEATURE_MATRIX[][2];
-    static const unsigned int FEATURE_MATRIX_EXCLUDE[][2];
+    static const unsigned int FEATURE_MATRIX_EXCLUDE[][4];
 
     State m_state;
     YK_KEY *m_yk;
